#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gitit
version:              0.15.1.2
visibility:           public
id:                   gitit-0.15.1.2-F68f5LYn9i690BN4bGIeek
key:                  gitit-0.15.1.2-F68f5LYn9i690BN4bGIeek
license:              LicenseRef-GPL
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
stability:            experimental
synopsis:             Wiki using happstack, git or darcs, and pandoc.
description:
    Gitit is a wiki backed by a git, darcs, or mercurial
    filestore.  Pages and uploaded files can be modified either
    directly via the VCS'\''s command-line tools or through
    the wiki'\''s web interface. Pandoc is used for markup
    processing, so pages may be written in
    (extended) markdown, reStructuredText, LaTeX, HTML,
    or literate Haskell.

    Notable features include

    * plugins: dynamically loaded page
    transformations written in Haskell (see
    "Network.Gitit.Interface")

    * conversion of TeX math to MathML for display in
    web browsers

    * syntax highlighting of source code
    files and code snippets

    * Atom feeds (site-wide and per-page)

    * a library, "Network.Gitit", that makes it simple
    to include a gitit wiki in any happstack application

    For usage information:  @gitit --help@

category:             Network
abi:                  6fea20a63b136987954cdf858aa5601d
exposed:              True
exposed-modules:
    Network.Gitit Network.Gitit.Authentication
    Network.Gitit.Authentication.Github Network.Gitit.Cache
    Network.Gitit.Compat.Except Network.Gitit.Config
    Network.Gitit.ContentTransformer Network.Gitit.Feed
    Network.Gitit.Framework Network.Gitit.Handlers
    Network.Gitit.Initialize Network.Gitit.Interface
    Network.Gitit.Layout Network.Gitit.Page Network.Gitit.Plugins
    Network.Gitit.Rpxnow Network.Gitit.Server Network.Gitit.State
    Network.Gitit.Types Network.Gitit.Util Paths_gitit

import-dirs:          /usr/lib/ghc-9.6.6/site-local/gitit-0.15.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gitit-0.15.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gitit-0.15.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/gitit
hs-libraries:         HSgitit-0.15.1.2-F68f5LYn9i690BN4bGIeek
depends:
    HStringTemplate-0.8.8-6KUpCGdXM3NLUGXz4uPpUY
    HTTP-4000.4.1-68SlQg4wFv5INxOHC0fbyj
    SHA-1.6.4.4-KRZJCS52poaHfqPlW5b8Sg
    aeson-2.2.1.0-BfV39Vpjeh9G4TP9CsFVxm base-4.18.2.1
    base64-bytestring-1.2.1.0-746voJok0ldKgJVOvUeNqZ
    blaze-html-0.9.2.0-BKWjU59gxaViX2FQhmEdd bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.8.5
    doctemplates-0.11.0.1-1hk2qfBOzExLBfsRi6yNGl
    feed-1.3.2.1-1VWwqUgEMFLHQmqTIxOr84 filepath-1.4.300.1
    filestore-0.6.5.1-ClsF4zF0BQdDo1K7H6TBdN ghc-9.6.6
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    happstack-server-7.9.3-CVIk72xoUb6CdcZ6ZCk9ed
    hoauth2-2.14.0-5vOhEFEQrcQIgdjP3PoEFP
    hslogger-1.3.2.0-FijSAonJ7uBH37tQKjVUz6
    http-client-tls-0.3.6.4-1EC6Bajh6K7FgvqmScIMPu
    http-conduit-2.3.9.1-EbXCCLQkoa7dekBqQfcAG
    json-0.10-Ay29YAmngbm32rGZP770LE mtl-2.3.1
    network-3.1.4.0-9YNBV8UGnKyEcMIeWoZU
    network-bsd-2.8.1.0-HSRnHKsRtRc73HaWRgg9z3
    network-uri-2.6.4.2-Gnw0MjQFVGhFnasOtB45
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    old-time-1.1.0.4-3lD0LwNFkdkGhWCMuxpBlx
    pandoc-3.5-KrRlBiYqMVkF1yOFLBqQZ5
    pandoc-types-1.23.1-CgcSIKGuhV0L2IvM6isbYF parsec-3.1.16.1
    pretty-1.1.3.6 process-1.6.19.0
    random-1.2.1.3-3jem7NfN1E34SkjZGu3Vjy
    recaptcha-0.1.0.4-3QFZ8G3XdN2IkRl0xOhpCS
    safe-0.3.21-44n8kxuoO3m8mzp6ewVaNo
    skylighting-0.14.4-2xzWfSib0NH1KTzXc8mtcY
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 syb-0.7.3-L7kiOZAm9FuLsEbHYQuF8P
    tagsoup-0.14.8-LNhRHjj75qGAr73Rttxl74
    temporary-1.3-vYPArfKPXAFeZtaQhptNG text-2.0.2 time-1.12.2
    uri-bytestring-0.3.3.1-3qPZKYG14C7Fb32fDYtKmA
    url-2.1.3-FnoMg0Amz5x5iDNEWuwHDq
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
    uuid-1.3.16-9HCSfEmPNfB3Ub0NyqmB3Q xhtml-3000.2.2.1
    xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt
    xml-conduit-1.9.1.4-EinTwPlhEXvICMqIr13G5A
    xml-types-0.3.8-ISf6rjkeTjSFXsXdIGBwau
    xss-sanitize-0.3.7.2-Fhj9fKhoKX6DsihZSIYHzn
    zlib-0.7.0.0-4xfXei9KqrR3TNrmcaLViZ

haddock-interfaces:   /usr/share/doc/gitit/html/gitit.haddock
haddock-html:         /usr/share/doc/gitit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

