/* ie.css */
body {text-align:center;}
.container {text-align:left;}
* html .column {overflow-x:hidden;}
* html legend {margin:-18px -8px 16px 0;padding:0;}
ol {margin-left:2em;}
sup {vertical-align:text-top;}
sub {vertical-align:text-bottom;}
html>body p code {*white-space:normal;}
hr {margin:-8px auto 11px;}
.container ul { list-style: disc outside; margin-left: 2em; } /* IE can't handle :before and :after */
.container ul li { text-indent: 0; margin-left: 0; }
.container legend { margin-bottom: 1.6em; } /* IE form margin bug */
sup, sub { font-size: 100%; } /* IE superscript & subscript bug */
.container blockquote p, #content blockquote ul, #content blockquote ol, #content blockquote dl, #content blockquote pre, #content blockquote address, 
.container blockquote table, #content blockquote form, #content blockquote h1, #content blockquote h2, #content blockquote h3, #content blockquote h4, #content blockquote h5, #content blockquote h6 { margin-top: .8em; margin-bottom: .8em; } /* IE can't handle :first-child */
* html .container textarea, * html .container input { padding: 0; } /* IE < 7 form fix */
.container input[type='submit'], .container input[type='button'] { padding: 0; } /* IE 7 button fix */
.container legend+* { margin-top: 0; } /* we already added legend margin */
a abbr, a acronym { text-decoration: underline; } /* IE 7 bug */
